/*
 *	VME Linux/m68k Loader
 *
 *	(c) Copyright 1997 by Nick Holgate
 *
 *	This file is subject to the terms and conditions of the GNU General Public
 *	License.  See the file COPYING for more details.
 */

/*--------------------------------------------------------------------------*/

#include "loader.h"

/*--------------------------------------------------------------------------*/
/*  Program Entry
 */

__asm__(".text\n"
__ALIGN_STR "\n"
".globl " SYMBOL_NAME_STR(_start) ";\n"
SYMBOL_NAME_STR(_start) ":\n"
"	jbra	(" SYMBOL_NAME_STR(Main) ");\n"
);

/*-----------------------------< end of file >------------------------------*/
